@@ -32,3 +32,24 @@ test_that("categorize works", {
   r <- categorize(x, breaks)
   expect_equivalent(r, c(NA, 1, NA, NA, NA))
 })
+
+
+test_that("categorize_impl/categorize_non_numeric equivalence", {
+  replicate(100, {
+    n <- 10
+    x <- rnorm(n) * 10
+
+    breaks_pop <- c(-Inf, -5:5, Inf)
+    b <- sort(sample(breaks_pop, n, replace = FALSE))
+    left <- sample(c(TRUE, FALSE), n, replace = TRUE)
+    x[c(3,5,7)] <- sample(breaks_pop, 3)
+
+    b[3] <- b[2]
+    b[8] <- b[7]
+    left[2:3] <- left[7:8] <- c(TRUE, FALSE)
+
+    ci <- categorize_impl(x, b, left)
+    cnn <- categorize_non_numeric(x, b, left)
+    expect_equal(ci, cnn)
+  })
+})
